[//]: # (werk v2)
# Remove unneeded fields when creating a site conection

key        | value
---------- | ---
date       | 2024-12-27T11:15:16+00:00
version    | 2.3.0p26
class      | fix
edition    | cre
component  | rest-api
level      | 1
compatible | no

When creating a site with configuration replication disabled, many unneeded fields were mandatory.
This change fixes that, and the user should update the `configuration_connection` attribute as
follows to create or update a site without configuration replication:

```
  "configuration_connection" : {
     "enable_replication": false
  }
```

Prior to this change, the following is a typical payload for adding a remote site without
configuration replication:

```
{
    "basic_settings": {
        "alias": "Remote site 1",
        "site_id": "site_id_1"
    },
    "status_connection": {...},
        "connect_timeout": 2,
        "persistent_connection": false,
        "url_prefix": "/remote_site_1/",
        "status_host": {"status_host_set": "disabled"},
        "disable_in_status_gui": false
    },
    "configuration_connection": {
        "enable_replication": false,
        "url_of_remote_site": "http://localhost/remote_site_1/check_mk/",
        "disable_remote_configuration": true,
        "ignore_tls_errors": false,
        "direct_login_to_web_gui_allowed": true,
        "user_sync": {
            "sync_with_ldap_connections": "all"
        },
        "replicate_event_console": true,
        "replicate_extensions": true,
        "message_broker_port": 5672
    }
}
```

After this change, the previous payload should be updated to this one:

```
{
    "basic_settings": {
        "alias": "Remote site 1",
        "site_id": "site_id_1"
    },
    "status_connection": {...},
        "connect_timeout": 2,
        "persistent_connection": false,
        "url_prefix": "/remote_site_1/",
        "status_host": {"status_host_set": "disabled"},
        "disable_in_status_gui": false
    },
    "configuration_connection": {
        "enable_replication": false,
    }
}
```
